# MLE Decathlon

[![Upload Python Package](https://github.com/Pie33000/mle_deacthlon/actions/workflows/python-publish.yml/badge.svg?branch=main)](https://github.com/Pie33000/mle_deacthlon/actions/workflows/python-publish.yml)
